cwlVersion: v1.2
class: Workflow
doc: >-
  The workflow starts with a gene set created from Example gene set. CTD is
  applied which diffuses through all nodes in STRING[1] to identify nodes that
  are "guilty by association" and highly connected to the initial gene set of
  interest[2][3]. A list of Highly Connected Genes was obtained from the CTD
  output. A list of Guilty By Association Genes was obtained from the CTD
  output. 

  1. Szklarczyk, D. et al. STRING v10: protein–protein interaction networks,
  integrated over the tree of life. Nucleic Acids Research vol. 43 D447–D452
  (2014). doi:10.1093/nar/gku1003

  2. Thistlethwaite, L. R. et al. Correction: CTD: An information-theoretic
  algorithm to interpret sets of metabolomic and transcriptomic perturbations in
  the context of graphical models. PLOS Computational Biology vol. 17 e1009551
  (2021). doi:10.1371/journal.pcbi.1009551

  3. Petrosyan, V. et al. Identifying biomarkers of differential chemotherapy
  response in TNBC patient-derived xenografts with a CTD/WGCNA approach.
  iScience vol. 26 105799 (2023). doi:10.1016/j.isci.2022.105799
requirements: {}
inputs:
  step-1-data:
    label: Gene Set Input
    doc: Start with a set of Genes
    type: File
outputs:
  step-1-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-1/output
  step-2-output:
    label: CTD Response Info
    doc: ""
    type: File
    outputSource: step-2/output
  step-3-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-3/output
  step-4-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-4/output
steps:
  step-1:
    run: Input[Set[Gene]].cwl
    label: Gene Set Input
    doc: Start with a set of Genes
    in:
      data:
        source: step-1-data
      outputFilename:
        default: step-1-output.json
    out:
      - output
  step-2:
    run: GeneSet_CTD_String.cwl
    label: CTD - Connect the Dots in STRING
    doc: Use CTD to "Connect the Dots" and identify highly connected set of proteins
      in the STRING protein interaction graph. *Please note 10-150 genes of
      interest are required to run CTD
    in:
      inputs.geneset:
        label: Gene Set
        source: step-1/output
      outputFilename:
        default: step-2-output.json
    out:
      - output
  step-3:
    run: Highly_Connected_Genes.cwl
    label: Extract Highly Connected Genes
    doc: Extract nodes that are determined to be highly connected by CTD in your
      initial node set and display them in a table.
    in:
      inputs.ctdResponseInfo:
        label: CTD Response Info
        source: step-2/output
      outputFilename:
        default: step-3-output.json
    out:
      - output
  step-4:
    run: Guilty_By_Association_Genes.cwl
    label: Extract Guilty By Association Genes
    doc: Extract nodes that are "guilty by association" and connect your initial
      genes of interest within the graph.
    in:
      inputs.ctdResponseInfo:
        label: CTD Response Info
        source: step-2/output
      outputFilename:
        default: step-4-output.json
    out:
      - output
